--[[
-- Handles mod configuration with a Settings object
--]]

-- Load default settings
natural_slopes.default_settings = Settings(minetest.get_modpath(minetest.get_current_modname()) .. "/default_settings.conf")
-- Load world settings if any
natural_slopes.settings = Settings(minetest.get_worldpath() .. "/natural_slopes_settings.conf")

--- Get the full name of a setting.
local function full_name(name)
	return 'natural_slopes.' .. name
end

--- Get mod settings value. To get a boolean value use setting_getbool
-- @param name Name of the setting, without 'natural_slopes' prefix.
-- @return The value read from world settings or default settings if not set.
function natural_slopes.setting_get(name)
	if natural_slopes.settings then
		local value = natural_slopes.settings:get(full_name(name))
		if value then return value end
	end
	return natural_slopes.default_settings:get(full_name(name))
end

--- Get mod settings boolean value.
-- @param name Name of the setting, without 'natural_slope' prefix.
-- @return The value read from world settings or default settings if not set.
function natural_slopes.setting_getbool(name)
	local full_name = "natural_slopes." .. name
	if natural_slopes.settings then
		local value = natural_slopes.settings:get_bool(full_name(name))
		if value ~= nil then return value end
	end
	return natural_slopes.default_settings:get_bool(full_name(name))
end

